=======
Catalog
=======

Interface with data catalogs.

.. raw:: html

    <style>
      div.sd-card-body.docutils li.toctree-l1 > :first-child {display: none;}
    </style>

.. grid::

    .. grid-item-card::

        **Unity Catalog**
        ^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 3

           unity
